@@ -1,11 +1,11 @@
 import datetime
 
 import pytest
+from almost_equal import datetime_almost_equal
+
 from astral import sun
 from astral.location import Location
 
-from almost_equal import datetime_almost_equal
-
 
 @pytest.mark.parametrize(
     "day,dawn",
@@ -17,7 +17,9 @@ from almost_equal import datetime_almost_equal
         (datetime.date(2015, 12, 25), datetime.datetime(2015, 12, 25, 6, 45)),
     ],
 )
-def test_Sun_Local_tzinfo(day:datetime.date, dawn:datetime.datetime, new_delhi:Location):
+def test_Sun_Local_tzinfo(
+    day: datetime.date, dawn: datetime.datetime, new_delhi: Location
+):
     dawn = dawn.replace(tzinfo=new_delhi.tzinfo)
     dawn_calc = sun.sun(new_delhi.observer, day, 6.0, new_delhi.tzinfo)["dawn"]
     assert datetime_almost_equal(dawn, dawn_calc)
@@ -33,7 +35,9 @@ def test_Sun_Local_tzinfo(day:datetime.date, dawn:datetime.datetime, new_delhi:L
         (datetime.date(2015, 12, 25), datetime.datetime(2015, 12, 25, 6, 45)),
     ],
 )
-def test_Sun_Local_str(day:datetime.date, dawn:datetime.datetime, new_delhi:Location):
+def test_Sun_Local_str(
+    day: datetime.date, dawn: datetime.datetime, new_delhi: Location
+):
     dawn = dawn.replace(tzinfo=new_delhi.tzinfo)
     dawn_calc = sun.sun(new_delhi.observer, day, 6.0, "Asia/Kolkata")["dawn"]
     assert datetime_almost_equal(dawn, dawn_calc)
